/*
** Module   : SecurityConstants.java
** Abstract : a shared definition of security-related constants
**
** Copyright (c) 2006-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- -------------------------- Description -----------------------------
** 001 GES 20061003   @30106 Created as a shared definition of security-related constants.
** 002 NVS 20090130   @41244 Added AUTH_REQ_PROGRAM constant.
** 003 SVL 20100916          Changed AUTH_MODE_LOWEST in order to include
**                           AUTH_MODE_NONE in the range.
** 004 OM  20131002          Added AUTH_MODE_METADATA, AUTH_RESULT_CANCEL_CURRENT and
**                           AUTH_REQ_DB_QUERY needed by database authenticator using meta table.
*/

package com.goldencode.p2j.security;

/**
 * A shared definition of security-related constants.
 */
public interface SecurityConstants
{
   /** Authorization mode: no override. */
   public static final int AUTH_MODE_NONE = 0;

   /** Authorization mode: the lowest value. */
   public static final int AUTH_MODE_LOWEST = 0;

   /** Authorization mode: user ID and password. */
   public static final int AUTH_MODE_IDPW = 1;

   /** Authorization mode: X.509 certificate. */
   public static final int AUTH_MODE_X509 = 2;

   /** Authorization mode: X.509 certificate and userID and password. */
   public static final int AUTH_MODE_X509_IDPW = 3;

   /** Authorization mode: custom. */
   public static final int AUTH_MODE_CUSTOM = 4;

   /** Authorization mode: the highest value. */
   public static final int AUTH_MODE_HIGHEST = 5;

   /** Authorization request type: USER. */
   public static final int AUTH_REQ_USER = 0;

   /** Authorization request type: PROCESS. */
   public static final int AUTH_REQ_PROCESS = 1;

   /** Authorization request type: PROGRAMMATIC */
   public static final int AUTH_REQ_PROGRAM = 2;

   /** Authorization result: no result. */
   public static final int AUTH_RESULT_NONE = -1;

   /** Authorization result: success. */
   public static final int AUTH_RESULT_SUCCESS = 0;

   /** Authorization result: unspecified failure. */
   public static final int AUTH_RESULT_UNSPECIFIED_FAILURE = 1;
   
   /** Authorization result: invalid user ID. */
   public static final int AUTH_RESULT_INVALID_USERID = 2;

   /** Authorization result: invalid password. */
   public static final int AUTH_RESULT_INVALID_PASSWORD = 3;

   /** Authorization result: insufficient account rights to logon. */
   public static final int AUTH_RESULT_INSUFFICIENT_RIGHTS = 4;

   /** Cancel current authorization. */
   public static final int AUTH_RESULT_SKIP_ENTITY = 5;

   /** Authorization action: authorization has been successfully completed. */
   public static final int AUTH_ACTION_DONE = 0;
   
   /** Authorization action: authorization should continue. */
   public static final int AUTH_ACTION_CONTINUE = 1;
   
   /** Authorization action: abort further processing immediately. */
   public static final int AUTH_ACTION_ABORT = 2;

   /** Authorization action: retry authentication. */
   public static final int AUTH_ACTION_RETRY = 3;

   /** The (symbolic) size of package represented by AUTH_RESULT_SKIP_ENTITY. */
   public static final int PKT_SIZE_SKIP_ENTITY = -1;
}
